@@ -1,11 +1,12 @@
 """Init file of GPT Index."""
-
 from pathlib import Path
 
 with open(Path(__file__).absolute().parents[0] / "VERSION") as _f:
     __version__ = _f.read().strip()
 
 
+from gpt_index.data_structs.struct_type import IndexStructType
+
 # embeddings
 from gpt_index.embeddings.langchain import LangchainEmbedding
 from gpt_index.embeddings.openai import OpenAIEmbedding
@@ -17,6 +18,12 @@ from gpt_index.indices.keyword_table import (
     GPTSimpleKeywordTableIndex,
 )
 from gpt_index.indices.list import GPTListIndex
+
+# prompt helper
+from gpt_index.indices.prompt_helper import PromptHelper
+
+# for composability
+from gpt_index.indices.query.schema import QueryConfig, QueryMode
 from gpt_index.indices.tree import GPTTreeIndex
 from gpt_index.indices.vector_store import (
     GPTFaissIndex,
@@ -41,16 +48,19 @@ from gpt_index.prompts.prompts import (
 )
 
 # readers
-from gpt_index.readers.file import SimpleDirectoryReader
-from gpt_index.readers.google.gdocs import GoogleDocsReader
-from gpt_index.readers.mongo import SimpleMongoReader
-from gpt_index.readers.notion import NotionPageReader
-
-# allow importing Document at the top-level
-from gpt_index.readers.schema.base import Document
-from gpt_index.readers.slack import SlackReader
-from gpt_index.readers.weaviate.reader import WeaviateReader
-from gpt_index.readers.wikipedia import WikipediaReader
+from gpt_index.readers import (
+    DiscordReader,
+    Document,
+    FaissReader,
+    GoogleDocsReader,
+    NotionPageReader,
+    PineconeReader,
+    SimpleDirectoryReader,
+    SimpleMongoReader,
+    SlackReader,
+    WeaviateReader,
+    WikipediaReader,
+)
 
 # token predictor
 from gpt_index.token_predictor.mock_chain_wrapper import MockLLMPredictor
@@ -83,6 +93,13 @@ __all__ = [
     "GoogleDocsReader",
     "SlackReader",
     "WeaviateReader",
+    "FaissReader",
+    "PineconeReader",
+    "DiscordReader",
     "LLMPredictor",
     "MockLLMPredictor",
+    "PromptHelper",
+    "QueryConfig",
+    "QueryMode",
+    "IndexStructType",
 ]
