@@ -14,11 +14,14 @@ from typing import (
     cast,
 )
 
-from gpt_index.data_structs import IndexStruct, IndexStructType
+from gpt_index.data_structs.data_structs import IndexStruct, Node
+from gpt_index.data_structs.struct_type import IndexStructType
 from gpt_index.indices.prompt_helper import PromptHelper
 from gpt_index.indices.query.query_runner import QueryRunner
 from gpt_index.indices.query.schema import QueryConfig, QueryMode
+from gpt_index.indices.utils import truncate_text
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
+from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
 from gpt_index.schema import BaseDocument, DocumentStore
 from gpt_index.utils import llm_token_counter
 
@@ -29,7 +32,21 @@ DOCUMENTS_INPUT = Union[BaseDocument, "BaseGPTIndex"]
 
 
 class BaseGPTIndex(Generic[IS]):
-    """Base GPT Index."""
+    """Base GPT Index.
+
+    Args:
+        documents (Optional[Sequence[BaseDocument]]): List of documents to
+            build the index from.
+        llm_predictor (LLMPredictor): Optional LLMPredictor object. If not provided,
+            will use the default LLMPredictor (text-davinci-003)
+        prompt_helper (PromptHelper): Optional PromptHelper object. If not provided,
+            will use the default PromptHelper.
+        chunk_size_limit (Optional[int]): Optional chunk size limit. If not provided,
+            will use the default chunk size limit (4096 max input size).
+        verbose (bool): Optional bool. If True, will print out additional information
+            during the index building process.
+
+    """
 
     index_struct_cls: Type[IS]
 
@@ -74,6 +91,11 @@ class BaseGPTIndex(Generic[IS]):
         """Get the docstore corresponding to the index."""
         return self._docstore
 
+    @property
+    def llm_predictor(self) -> LLMPredictor:
+        """Get the llm predictor."""
+        return self._llm_predictor
+
     def _process_documents(
         self, documents: Sequence[DOCUMENTS_INPUT], docstore: DocumentStore
     ) -> List[BaseDocument]:
@@ -111,6 +133,7 @@ class BaseGPTIndex(Generic[IS]):
         """
         # make sure that we generate text for index struct
         if self._index_struct.text is None:
+            # NOTE: set text to be empty string for now
             raise ValueError(
                 "Index must have text property set in order "
                 "to be composed with other indices. "
@@ -119,7 +142,7 @@ class BaseGPTIndex(Generic[IS]):
         return self._index_struct
 
     def set_text(self, text: str) -> None:
-        """Set text for index struct.
+        """Set summary text for index struct.
 
         This allows index_struct_with_text to be used to compose indices
         with other indices.
@@ -127,6 +150,28 @@ class BaseGPTIndex(Generic[IS]):
         """
         self._index_struct.text = text
 
+    def _get_nodes_from_document(
+        self,
+        document: BaseDocument,
+        text_splitter: TokenTextSplitter,
+        start_idx: int = 0,
+    ) -> List[Node]:
+        """Add document to index."""
+        text_chunks = text_splitter.split_text(document.get_text())
+        nodes = []
+        for i, text_chunk in enumerate(text_chunks):
+            fmt_text_chunk = truncate_text(text_chunk, 50)
+            print(f"> Adding chunk: {fmt_text_chunk}")
+            # if embedding specified in document, pass it to the Node
+            node = Node(
+                text=text_chunk,
+                index=start_idx + i,
+                ref_doc_id=document.get_doc_id(),
+                embedding=document.embedding,
+            )
+            nodes.append(node)
+        return nodes
+
     @abstractmethod
     def _build_index_from_documents(
         self, documents: Sequence[BaseDocument], verbose: bool = False
@@ -171,7 +216,7 @@ class BaseGPTIndex(Generic[IS]):
         query_str: str,
         verbose: bool = False,
         mode: str = QueryMode.DEFAULT,
-        **query_kwargs: Any
+        **query_kwargs: Any,
     ) -> str:
         """Answer a query.
 
